==> walkers-fabric-1.20.1-4.2-sources.jar: tocraft/walkers/mixin/client/PlayerEntityRendererMixin.java <==
package tocraft.walkers.mixin.client;

import com.google.common.collect.ImmutableList;
import com.llamalad7.mixinextras.injector.v2.WrapWithCondition;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1007;
import net.minecraft.class_1268;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1304;
import net.minecraft.class_1306;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1321;
import net.minecraft.class_1593;
import net.minecraft.class_1657;
import net.minecraft.class_1664;
import net.minecraft.class_243;
import net.minecraft.class_310;
import net.minecraft.class_3545;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5617;
import net.minecraft.class_572;
import net.minecraft.class_583;
import net.minecraft.class_591;
import net.minecraft.class_630;
import net.minecraft.class_742;
import net.minecraft.class_897;
import net.minecraft.class_909;
import net.minecraft.class_922;
import net.minecraft.world.entity.*;
import org.jetbrains.annotations.Contract;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import tocraft.walkers.Walkers;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.api.model.ArmRenderingManipulator;
import tocraft.walkers.api.model.EntityArms;
import tocraft.walkers.api.model.EntityUpdater;
import tocraft.walkers.api.model.EntityUpdaters;
import tocraft.walkers.impl.PlayerDataProvider;
import tocraft.walkers.mixin.accessor.EntityAccessor;
import tocraft.walkers.mixin.accessor.LivingEntityAccessor;
import tocraft.walkers.mixin.client.accessor.LimbAnimatorAccessor;
import tocraft.walkers.mixin.client.accessor.LivingEntityRendererAccessor;

import java.util.Optional;
import java.util.UUID;

@SuppressWarnings({"ALL", "unchecked"})
@Environment(EnvType.CLIENT)
@Mixin(class_1007.class)
public abstract class PlayerEntityRendererMixin extends class_922<class_742, class_591<class_742>> {

    @Contract(pure = true)
    @Shadow
    private static class_572.@Nullable class_573 getArmPose(class_742 player, class_1268 hand) {
        return null;
    }

    private PlayerEntityRendererMixin(class_5617.class_5618 ctx, class_591<class_742> model, float shadowRadius) {
        super(ctx, model, shadowRadius);
    }

    @WrapWithCondition(method = "render(Lnet/minecraft/client/player/AbstractClientPlayer;FFLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/renderer/entity/LivingEntityRenderer;render(Lnet/minecraft/world/entity/LivingEntity;FFLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V"))
    private boolean redirectRender(class_922<class_742, class_583<class_742>> renderer, class_1309 player, float f, float g, class_4587 matrixStack, class_4597 buffer, int i) {
        class_1309 shape = PlayerShape.getCurrentShape((class_1657) player);

        Optional<UUID> vehiclePlayerId = ((PlayerDataProvider) player).walkers$getVehiclePlayerUUID();
        if (vehiclePlayerId.isPresent()) {
            class_243 vehiclePos = player.method_5770().method_18470(vehiclePlayerId.get()).method_19538();
            player.method_29495(new class_243(vehiclePos.field_1352, vehiclePos.field_1351 + 1, vehiclePos.field_1350));
        }

        // sync player data to shape
        if (shape != null) {
            ((LimbAnimatorAccessor) shape.field_42108).setPrevSpeed(((LimbAnimatorAccessor) player.field_42108).getPrevSpeed());
            shape.field_42108.method_48567(player.field_42108.method_48566());
            ((LimbAnimatorAccessor) shape.field_42108).setPos(player.field_42108.method_48569());
            shape.field_6252 = player.field_6252;
            shape.field_6279 = player.field_6279;
            shape.field_6229 = player.field_6229;
            shape.field_6251 = player.field_6251;
            shape.field_6283 = player.field_6283;
            shape.field_6220 = player.field_6220;
            shape.field_6241 = player.field_6241;
            shape.field_6259 = player.field_6259;
            shape.field_6012 = player.field_6012;
            shape.field_6266 = player.field_6266;
            ((LivingEntityAccessor) shape).setSwimAmount(((LivingEntityAccessor) player).getSwimAmount());
            ((LivingEntityAccessor) shape).setSwimAmountO(((LivingEntityAccessor) player).getSwimAmountO());
            shape.method_24830(player.method_24828());
            shape.method_18799(player.method_18798());
            shape.method_5648(player.method_5756(class_310.method_1551().field_1724));

            ((EntityAccessor) shape).setVehicle(player.method_5854());
            ((EntityAccessor) shape).setPassengers(ImmutableList.copyOf(player.method_5685()));
            ((EntityAccessor) shape).setTouchingWater(player.method_5799());

            // phantoms' pitch is inverse for whatever reason
            if (shape instanceof class_1593) {
                shape.method_36457(-player.method_36455());
                shape.field_6004 = -player.field_6004;
            } else {
                shape.method_36457(player.method_36455());
                shape.field_6004 = player.field_6004;
            }

            // equip held items on shape
            if (Walkers.CONFIG.shapesEquipItems) {
                shape.method_5673(class_1304.field_6173, player.method_6118(class_1304.field_6173));
                shape.method_5673(class_1304.field_6171, player.method_6118(class_1304.field_6171));
            }

            // equip armor items on shape
            if (Walkers.CONFIG.shapesEquipArmor) {
                shape.method_5673(class_1304.field_6169, player.method_6118(class_1304.field_6169));
                shape.method_5673(class_1304.field_6174, player.method_6118(class_1304.field_6174));
                shape.method_5673(class_1304.field_6172, player.method_6118(class_1304.field_6172));
                shape.method_5673(class_1304.field_6166, player.method_6118(class_1304.field_6166));
            }

            if (shape instanceof class_1308) {
                ((class_1308) shape).method_19540(player.method_6115());
            }

            // Assign pose
            shape.method_18380(player.method_18376());

            // set active hand after configuring held items
            shape.method_6019(player.method_6058() == null ? class_1268.field_5808 : player.method_6058());
            ((LivingEntityAccessor) shape).callSetLivingEntityFlag(1, player.method_6115());
            shape.method_6048();
            ((LivingEntityAccessor) shape).callUpdatingUsingItem();
            shape.field_6235 = player.field_6235; // FIX: https://github.com/Draylar/identity/issues/424

            // update shape specific properties
            EntityUpdater<class_1309> entityUpdater = EntityUpdaters.getUpdater((class_1299<class_1309>) shape.method_5864());
            if (entityUpdater != null) {
                entityUpdater.update((class_1657) player, shape);
            }

            if (!player.method_5756(class_310.method_1551().field_1724) && !player.method_7325()) {
                class_897<class_1309> shapeRenderer = (class_897<class_1309>) class_310.method_1551().method_1561().method_3953(shape);

                // Sync biped information for stuff like bow drawing animation
                if (shapeRenderer instanceof class_909) {
                    shape_setBipedShapeModelPose((class_742) player, shape, (class_909<?, ?>) shapeRenderer);
                }

                shapeRenderer.method_3936(shape, f, g, matrixStack, buffer, i);

                // Only render nametags if the server option is true and the entity being
                // rendered is NOT this player/client
                if (Walkers.CONFIG.showPlayerNametag && player != class_310.method_1551().field_1724) {
                    method_3926((class_742) player, player.method_5476(), matrixStack, buffer, i);
                }
            }

            return false;
        } else {
            return true;
        }
    }

    @Unique
    private void shape_setBipedShapeModelPose(class_742 player, class_1309 shape, class_922<?, ?> shapeRenderer) {
        class_572<?> shapeBipedModel = (class_572<?>) shapeRenderer.method_4038();

        if (shape.method_7325()) {
            shapeBipedModel.method_2805(false);
            shapeBipedModel.field_3398.field_3665 = true;
            shapeBipedModel.field_3394.field_3665 = true;
        } else {
            shapeBipedModel.method_2805(true);
            shapeBipedModel.field_3394.field_3665 = player.method_7348(class_1664.field_7563);
            shapeBipedModel.field_3400 = shape.method_18276();

            class_572.class_573 mainHandPose = getArmPose(player, class_1268.field_5808);
            class_572.class_573 offHandPose = getArmPose(player, class_1268.field_5810);

            if (mainHandPose != null && mainHandPose.method_30156()) {
                offHandPose = shape.method_6079().method_7960() ? class_572.class_573.field_3409 : class_572.class_573.field_3410;
            }

            if ((mainHandPose != null && offHandPose != null) && shape.method_6068() == class_1306.field_6183) {
                shapeBipedModel.field_3395 = mainHandPose;
                shapeBipedModel.field_3399 = offHandPose;
            } else if (mainHandPose != null && offHandPose != null) {
                shapeBipedModel.field_3395 = offHandPose;
                shapeBipedModel.field_3399 = mainHandPose;
            }
        }
    }

    @Inject(method = "getRenderOffset(Lnet/minecraft/client/player/AbstractClientPlayer;F)Lnet/minecraft/world/phys/Vec3;", at = @At("HEAD"), cancellable = true)
    private void modifyPositionOffset(class_742 player, float f, CallbackInfoReturnable<class_243> cir) {
        class_1309 shape = PlayerShape.getCurrentShape(player);

        if (shape != null) {
            if (shape instanceof class_1321) {
                cir.setReturnValue(super.method_23169(player, f));
            }
        }
    }

    @Inject(method = "renderHand", at = @At("HEAD"), cancellable = true)
    private void onRenderArm(class_4587 matrices, class_4597 vertexConsumers, int light, class_742 player, class_630 arm, class_630 sleeve, CallbackInfo ci) {
        class_1309 shape = PlayerShape.getCurrentShape(player);

        // sync player data to shape
        if (shape != null) {
            class_897<?> renderer = class_310.method_1551().method_1561().method_3953(shape);

            if (renderer instanceof class_922) {
                class_922<class_1309, ?> rendererCasted = (class_922<class_1309, ?>) renderer;
                class_583 model = ((class_922<?, ?>) renderer).method_4038();

                // re-assign arm & sleeve models
                arm = null;
                sleeve = null;

                if (model instanceof class_591) {
                    arm = ((class_591<?>) model).field_3401;
                    sleeve = ((class_591<?>) model).field_3486;
                } else if (model instanceof class_572) {
                    arm = ((class_572<?>) model).field_3401;
                    sleeve = null;
                } else {
                    class_3545<class_630, ArmRenderingManipulator<class_583<class_1297>>> pair = EntityArms.get(shape, model);
                    if (pair != null) {
                        arm = pair.method_15442();
                        pair.method_15441().run(matrices, model);
                        matrices.method_22904(0, -.35, .5);
                    }
                }

                // assign model properties
                model.field_3447 = 0.0F;
//                model.sneaking = false;
//                model.leaningPitch = 0.0F;
                model.method_2819(shape, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F);

                // render
                if (arm != null) {
                    arm.field_3654 = 0.0F;
                    arm.method_22698(matrices, vertexConsumers.getBuffer(((LivingEntityRendererAccessor) rendererCasted).callGetRenderType(shape, true, false, true)), light, class_4608.field_21444);
                }

                if (sleeve != null) {
                    sleeve.field_3654 = 0.0F;
                    sleeve.method_22698(matrices, vertexConsumers.getBuffer(((LivingEntityRendererAccessor) rendererCasted).callGetRenderType(shape, true, false, true)), light, class_4608.field_21444);
                }

                ci.cancel();
            }
        }
    }
}

==> walkers-fabric-1.20.1-5.6-sources.jar: tocraft/walkers/mixin/client/PlayerEntityRendererMixin.java <==
package tocraft.walkers.mixin.client;

import com.google.common.collect.ImmutableList;
import com.llamalad7.mixinextras.injector.v2.WrapWithCondition;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1007;
import net.minecraft.class_1268;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1304;
import net.minecraft.class_1306;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1321;
import net.minecraft.class_1593;
import net.minecraft.class_1657;
import net.minecraft.class_1664;
import net.minecraft.class_243;
import net.minecraft.class_310;
import net.minecraft.class_3545;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5617;
import net.minecraft.class_572;
import net.minecraft.class_583;
import net.minecraft.class_591;
import net.minecraft.class_630;
import net.minecraft.class_742;
import net.minecraft.class_897;
import net.minecraft.class_909;
import net.minecraft.class_922;
import net.minecraft.world.entity.*;
import org.jetbrains.annotations.Contract;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import tocraft.craftedcore.patched.CEntity;
import tocraft.craftedcore.util.Maths;
import tocraft.walkers.Walkers;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.api.model.ArmRenderingManipulator;
import tocraft.walkers.api.model.EntityArms;
import tocraft.walkers.api.model.EntityUpdater;
import tocraft.walkers.api.model.EntityUpdaters;
import tocraft.walkers.mixin.accessor.EntityAccessor;
import tocraft.walkers.mixin.accessor.LivingEntityAccessor;
//#if MC>1182
import tocraft.walkers.mixin.client.accessor.LimbAnimatorAccessor;
//#endif
import tocraft.walkers.mixin.client.accessor.LivingEntityRendererAccessor;

@SuppressWarnings({"ALL", "unchecked"})
@Environment(EnvType.CLIENT)
@Mixin(class_1007.class)
public abstract class PlayerEntityRendererMixin extends class_922<class_742, class_591<class_742>> {

    @Contract(pure = true)
    @Shadow
    private static class_572.@Nullable class_573 getArmPose(class_742 player, class_1268 hand) {
        return null;
    }

    private PlayerEntityRendererMixin(class_5617.class_5618 ctx, class_591<class_742> model, float shadowRadius) {
        super(ctx, model, shadowRadius);
    }

    @WrapWithCondition(method = "render(Lnet/minecraft/client/player/AbstractClientPlayer;FFLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/renderer/entity/LivingEntityRenderer;render(Lnet/minecraft/world/entity/LivingEntity;FFLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V"))
    private boolean redirectRender(class_922<class_742, class_583<class_742>> renderer, class_1309 player, float f, float g, class_4587 matrixStack, class_4597 buffer, int packedLight) {
        class_1309 shape = PlayerShape.getCurrentShape((class_1657) player);

        // sync player data to shape
        if (shape != null) {
            // don't render passenger in first person to prevent a glichted view
            if (class_310.method_1551().field_1690.method_31044().method_31034() && player.method_5854() == class_310.method_1551().field_1719) {
                return false;
            }

            //#if MC>1182
            ((LimbAnimatorAccessor) shape.field_42108).setPrevSpeed(((LimbAnimatorAccessor) player.field_42108).getPrevSpeed());
            shape.field_42108.method_48567(player.field_42108.method_48566());
            ((LimbAnimatorAccessor) shape.field_42108).setPos(player.field_42108.method_48569());
            //#else
            //$$ shape.animationSpeedOld = player.animationSpeedOld;
            //$$ shape.animationSpeed = player.animationSpeed;
            //$$ shape.animationPosition = player.animationPosition;
            //#endif
            shape.field_6252 = player.field_6252;
            shape.field_6279 = player.field_6279;
            shape.field_6229 = player.field_6229;
            shape.field_6251 = player.field_6251;
            shape.field_6283 = player.field_6283;
            shape.field_6220 = player.field_6220;
            shape.field_6241 = player.field_6241;
            shape.field_6259 = player.field_6259;
            shape.field_6012 = player.field_6012;
            shape.field_6266 = player.field_6266;
            ((LivingEntityAccessor) shape).setSwimAmount(((LivingEntityAccessor) player).getSwimAmount());
            ((LivingEntityAccessor) shape).setSwimAmountO(((LivingEntityAccessor) player).getSwimAmountO());
            shape.method_24830(CEntity.isOnGround(player));
            shape.method_18799(player.method_18798());
            shape.method_5648(player.method_5756(class_310.method_1551().field_1724));

            ((EntityAccessor) shape).setVehicle(player.method_5854());
            ((EntityAccessor) shape).setPassengers(ImmutableList.copyOf(player.method_5685()));
            ((EntityAccessor) shape).setTouchingWater(player.method_5799());

            // phantoms' pitch is inverse for whatever reason
            if (shape instanceof class_1593) {
                shape.method_36457(-player.method_36455());
                shape.field_6004 = -player.field_6004;
            } else {
                shape.method_36457(player.method_36455());
                shape.field_6004 = player.field_6004;
            }

            // equip held items on shape
            if (Walkers.CONFIG.shapesEquipItems) {
                shape.method_5673(class_1304.field_6173, player.method_6118(class_1304.field_6173));
                shape.method_5673(class_1304.field_6171, player.method_6118(class_1304.field_6171));
            }

            // equip armor items on shape
            if (Walkers.CONFIG.shapesEquipArmor) {
                shape.method_5673(class_1304.field_6169, player.method_6118(class_1304.field_6169));
                shape.method_5673(class_1304.field_6174, player.method_6118(class_1304.field_6174));
                shape.method_5673(class_1304.field_6172, player.method_6118(class_1304.field_6172));
                shape.method_5673(class_1304.field_6166, player.method_6118(class_1304.field_6166));
            }

            if (shape instanceof class_1308) {
                ((class_1308) shape).method_19540(player.method_6115());
            }

            // Assign pose
            shape.method_18380(player.method_18376());

            // set active hand after configuring held items
            shape.method_6019(player.method_6058() == null ? class_1268.field_5808 : player.method_6058());
            ((LivingEntityAccessor) shape).callSetLivingEntityFlag(1, player.method_6115());
            shape.method_6048();
            ((LivingEntityAccessor) shape).callUpdatingUsingItem();
            shape.field_6235 = player.field_6235; // FIX: https://github.com/Draylar/identity/issues/424

            // update shape specific properties
            EntityUpdater<class_1309> entityUpdater = EntityUpdaters.getUpdater((class_1299<class_1309>) shape.method_5864());
            if (entityUpdater != null) {
                entityUpdater.update((class_1657) player, shape);
            }

            if (!player.method_5756(class_310.method_1551().field_1724) && !player.method_7325()) {
                class_897<class_1309> shapeRenderer = (class_897<class_1309>) class_310.method_1551().method_1561().method_3953(shape);

                // Sync biped information for stuff like bow drawing animation
                if (shapeRenderer instanceof class_909) {
                    shape_setBipedShapeModelPose((class_742) player, shape, (class_909<?, ?>) shapeRenderer);
                }

                shapeRenderer.method_3936(shape, f, g, matrixStack, buffer, packedLight);

                // Only render nametags if the server option is true and the entity being
                // rendered is NOT this player/client
                if (Walkers.CONFIG.showPlayerNametag && player != class_310.method_1551().field_1724) {
                    //#if MC>=1205
                    method_3926((class_742) player, player.method_5476(), matrixStack, buffer, packedLight, 0);
                    //#else
                    //$$ renderNameTag((AbstractClientPlayer) player, player.getDisplayName(), matrixStack, buffer, packedLight);
                    //#endif
                }
            }

            return false;
        } else {
            return true;
        }
    }

    @Unique
    private void shape_setBipedShapeModelPose(class_742 player, class_1309 shape, class_922<?, ?> shapeRenderer) {
        class_572<?> shapeBipedModel = (class_572<?>) shapeRenderer.method_4038();

        if (shape.method_7325()) {
            shapeBipedModel.method_2805(false);
            shapeBipedModel.field_3398.field_3665 = true;
            shapeBipedModel.field_3394.field_3665 = true;
        } else {
            shapeBipedModel.method_2805(true);
            shapeBipedModel.field_3394.field_3665 = player.method_7348(class_1664.field_7563);
            shapeBipedModel.field_3400 = shape.method_18276();

            class_572.class_573 mainHandPose = getArmPose(player, class_1268.field_5808);
            class_572.class_573 offHandPose = getArmPose(player, class_1268.field_5810);

            if (mainHandPose != null && mainHandPose.method_30156()) {
                offHandPose = shape.method_6079().method_7960() ? class_572.class_573.field_3409 : class_572.class_573.field_3410;
            }

            if ((mainHandPose != null && offHandPose != null) && shape.method_6068() == class_1306.field_6183) {
                shapeBipedModel.field_3395 = mainHandPose;
                shapeBipedModel.field_3399 = offHandPose;
            } else if (mainHandPose != null && offHandPose != null) {
                shapeBipedModel.field_3395 = offHandPose;
                shapeBipedModel.field_3399 = mainHandPose;
            }
        }
    }

    @Inject(method = "getRenderOffset(Lnet/minecraft/client/player/AbstractClientPlayer;F)Lnet/minecraft/world/phys/Vec3;", at = @At("HEAD"), cancellable = true)
    private void modifyPositionOffset(class_742 player, float f, CallbackInfoReturnable<class_243> cir) {
        class_1309 shape = PlayerShape.getCurrentShape(player);

        if (shape != null) {
            if (shape instanceof class_1321) {
                cir.setReturnValue(super.method_23169(player, f));
            }
        }
    }

    @Inject(method = "renderHand", at = @At("HEAD"), cancellable = true)
    private void onRenderArm(class_4587 matrices, class_4597 vertexConsumers, int light, class_742 player, class_630 arm, class_630 sleeve, CallbackInfo ci) {
        class_1309 shape = PlayerShape.getCurrentShape(player);

        // sync player data to shape
        if (shape != null) {
            class_897<?> renderer = class_310.method_1551().method_1561().method_3953(shape);

            if (renderer instanceof class_922) {
                class_922<class_1309, ?> rendererCasted = (class_922<class_1309, ?>) renderer;
                class_583 model = ((class_922<?, ?>) renderer).method_4038();

                // re-assign arm & sleeve models
                arm = null;
                sleeve = null;

                if (model instanceof class_572) {
                    if (player.method_6068() == class_1306.field_6183) {
                        arm = ((class_572<?>) model).field_3401;
                    } else {
                        arm = ((class_572<?>) model).field_27433;
                    }
                    if (model instanceof class_591) {
                        sleeve = ((class_591<?>) model).field_3486;
                    }
                } else {
                    class_3545<class_630, ArmRenderingManipulator<class_583<class_1297>>> pair = EntityArms.get(shape, model);
                    if (pair != null) {
                        arm = pair.method_15442();
                        // mirror matrices with player is left-handed
                        if (player.method_6068() == class_1306.field_6182) {
                            matrices.method_22907(Maths.getDegreesQuaternion(Maths.POSITIVE_Y(), 180));
                        }
                        pair.method_15441().run(matrices, model);
                        matrices.method_22904(0, -.35, .5);
                    }
                }

                // assign model properties
                model.field_3447 = 0.0F;
//                model.sneaking = false;
//                model.leaningPitch = 0.0F;
                model.method_2819(shape, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F);

                // render
                if (arm != null) {
                    arm.field_3654 = 0.0F;
                    arm.method_22698(matrices, vertexConsumers.getBuffer(((LivingEntityRendererAccessor) rendererCasted).callGetRenderType(shape, true, false, true)), light, class_4608.field_21444);
                }

                if (sleeve != null) {
                    sleeve.field_3654 = 0.0F;
                    sleeve.method_22698(matrices, vertexConsumers.getBuffer(((LivingEntityRendererAccessor) rendererCasted).callGetRenderType(shape, true, false, true)), light, class_4608.field_21444);
                }

                ci.cancel();
            }
        }
    }
}
